TextPos

Enum TextPos 

pub enum TextPos {
    Char(usize),
    Line(usize),
    End,
}
A position in the text for the bounds of a rewrite range.

Resolves to a character index (0-based) for the half-open range [from, to). A bare usize is treated as a character index (via From<usize>); [line] sets the start of a line, infinite — the end of the text.

Variants



Char(usize)

A character index (0-based, Unicode scalar). Clamped to [0, length].



Line(usize)

The start of line n (0-based) — the boundary before its first character. Lines are separated by \n. An index past the last line is the end of the text.



End

The end of the text. Valid primarily as to (for from it equals the length, i.e. an empty range at the end). Constructed via infinite.